var searchData=
[
  ['v0',['v0',['../a00110.html#abacd9a21d5a78d80dc1faf617caf39e9',1,'OpenMesh::Decimater::CollapseInfoT::v0()'],['../a00192.html#a44653fa3b86bab7a3e8d1b7ba192f126',1,'OpenMesh::Decimater::ModProgMeshT::Info::v0()']]],
  ['v0v1',['v0v1',['../a00110.html#a5167e49665056a7a8b6bcc6b6915c09e',1,'OpenMesh::Decimater::CollapseInfoT']]],
  ['v0vl',['v0vl',['../a00110.html#a4df2f92321dbd926da6c830a22346d6c',1,'OpenMesh::Decimater::CollapseInfoT']]],
  ['v1',['v1',['../a00110.html#a7e472c32525398eeb34cad7c52aa3651',1,'OpenMesh::Decimater::CollapseInfoT::v1()'],['../a00192.html#a0c2c4d240af26c492a5178f8c0b2ed32',1,'OpenMesh::Decimater::ModProgMeshT::Info::v1()']]],
  ['v1v0',['v1v0',['../a00110.html#a53dc5ea9882b3097b8281142c0bdb225',1,'OpenMesh::Decimater::CollapseInfoT']]],
  ['v1vr',['v1vr',['../a00110.html#a67375650879904935d62e544285aa0f9',1,'OpenMesh::Decimater::CollapseInfoT']]],
  ['valence',['valence',['../a00247.html#ac618157eb72688342d66fd76610ef509',1,'OpenMesh::PolyConnectivity::valence(VertexHandle _vh) const '],['../a00247.html#a4536e7f7a213fc4163113c0366c2e8a9',1,'OpenMesh::PolyConnectivity::valence(FaceHandle _fh) const ']]],
  ['value_5ftype',['value_type',['../a00313.html#a3e732770fcb2ed625ac0f46b271ea5e0',1,'VectorT::value_type()'],['../a00295.html#a127a4d7ca521ed3254cd801917ee67d4',1,'OpenMesh::vector_traits::value_type()']]],
  ['vde',['VdE',['../a00287.html',1,'OpenMesh::Subdivider::Adaptive']]],
  ['vde',['VdE',['../a00117.html#acd243b4d3e60a7b67ddd7f3437e51010',1,'OpenMesh::Subdivider::Uniform::CompositeT']]],
  ['vdec',['VdEc',['../a00288.html',1,'OpenMesh::Subdivider::Adaptive']]],
  ['vdec',['VdEc',['../a00117.html#a787f2e616ae6b4e0cf5c5f7951d783b2',1,'OpenMesh::Subdivider::Uniform::CompositeT']]],
  ['vdeg',['VdEg',['../a00117.html#a6a75fc51769d2f972cca10beb52c4494',1,'OpenMesh::Subdivider::Uniform::CompositeT::VdEg(Coeff &amp;_coeff)'],['../a00117.html#a1500a850dcfa332546c202048be25daa',1,'OpenMesh::Subdivider::Uniform::CompositeT::VdEg(scalar_t _gamma)']]],
  ['view_20dependent_20progressive_20meshes',['View Dependent Progressive Meshes',['../a00070.html',1,'tools_docu']]],
  ['vdpmsynthesizerviewerwidget',['VDPMSynthesizerViewerWidget',['../a00289.html',1,'OpenMesh']]],
  ['ve',['VE',['../a00290.html',1,'OpenMesh::Subdivider::Adaptive']]],
  ['ve',['VE',['../a00117.html#ac33806fb9f809971a3dfe4c228507a76',1,'OpenMesh::Subdivider::Uniform::CompositeT']]],
  ['ve_5fbegin',['ve_begin',['../a00247.html#a648caacd185466edcd99e59d5160a625',1,'OpenMesh::PolyConnectivity']]],
  ['ve_5fccwbegin',['ve_ccwbegin',['../a00247.html#ad0f37f5e4f99a2e0dec5b26e69138c40',1,'OpenMesh::PolyConnectivity']]],
  ['ve_5fccwend',['ve_ccwend',['../a00247.html#aa14ab7f50668a03e82a800d9291b201e',1,'OpenMesh::PolyConnectivity']]],
  ['ve_5fccwiter',['ve_ccwiter',['../a00247.html#a7c57d8a8724fc4c3c29e967c23e4fb55',1,'OpenMesh::PolyConnectivity']]],
  ['ve_5fcwbegin',['ve_cwbegin',['../a00247.html#a38ddc565f9c5d5311f79aecf058d3c25',1,'OpenMesh::PolyConnectivity']]],
  ['ve_5fcwend',['ve_cwend',['../a00247.html#a942298c59e521e1b4b82f63c21095923',1,'OpenMesh::PolyConnectivity']]],
  ['ve_5fcwiter',['ve_cwiter',['../a00247.html#ae191bb6212d2639f808d0b8563aa9c9e',1,'OpenMesh::PolyConnectivity']]],
  ['ve_5fend',['ve_end',['../a00247.html#a543516ab6aa52542f354083bc26270a2',1,'OpenMesh::PolyConnectivity']]],
  ['ve_5fiter',['ve_iter',['../a00247.html#af695c0e03e74577d8d97347ca84b1ff2',1,'OpenMesh::PolyConnectivity']]],
  ['ve_5frange',['ve_range',['../a00247.html#a017d1ebe6abae6877031b6667e4d58ba',1,'OpenMesh::PolyConnectivity']]],
  ['vec1c',['Vec1c',['../a00734.html#ace21cbe0734be4923a5445d677df3750',1,'OpenMesh']]],
  ['vec1d',['Vec1d',['../a00734.html#a366a34e2555ee0b3683dcbad76d1f712',1,'OpenMesh']]],
  ['vec1f',['Vec1f',['../a00734.html#ab22f9bcb1e3a5f99ec24b54216268904',1,'OpenMesh']]],
  ['vec1i',['Vec1i',['../a00734.html#a172138ea23399b5917940c173429820d',1,'OpenMesh']]],
  ['vec1s',['Vec1s',['../a00734.html#ac186f2be1057081015b7f6f64172d595',1,'OpenMesh']]],
  ['vec1uc',['Vec1uc',['../a00734.html#a9e8bcb7d076627397e2a90dfa1e3cfa2',1,'OpenMesh']]],
  ['vec1ui',['Vec1ui',['../a00734.html#aca20ed04a4ccc54f45b63ceafd7cf977',1,'OpenMesh']]],
  ['vec1us',['Vec1us',['../a00734.html#aab0f4b8f1df5ccee47c96db0f9c33f5b',1,'OpenMesh']]],
  ['vec2c',['Vec2c',['../a00734.html#a7d5b0af50881427adda78bfb8d0a5fb7',1,'OpenMesh']]],
  ['vec2d',['Vec2d',['../a00734.html#a42e2d2e555544695c8bcbbccdc954509',1,'OpenMesh']]],
  ['vec2f',['Vec2f',['../a00734.html#a3f1cd91001ec39807052adbada41f8ad',1,'OpenMesh']]],
  ['vec2i',['Vec2i',['../a00734.html#a76230fd62739cb1e06b1c3a618f24684',1,'OpenMesh']]],
  ['vec2s',['Vec2s',['../a00734.html#a714c3237ddf96ceb64c0589718862704',1,'OpenMesh']]],
  ['vec2uc',['Vec2uc',['../a00734.html#a9991db626a51250bb2cd71bda35b9080',1,'OpenMesh']]],
  ['vec2ui',['Vec2ui',['../a00734.html#a31eccbc258f88ba66520c93821b62aa9',1,'OpenMesh']]],
  ['vec2us',['Vec2us',['../a00734.html#a7d70e2895e7394338f176a1b66cf3a3d',1,'OpenMesh']]],
  ['vec3b',['Vec3b',['../a00734.html#ac4deee3421bb7439b5cda14f1616b844',1,'OpenMesh']]],
  ['vec3c',['Vec3c',['../a00734.html#a004cd72cc5bdc21492da277e36e39e87',1,'OpenMesh']]],
  ['vec3d',['Vec3d',['../a00734.html#a0d0d12b328b4ed0facca69be164cb8be',1,'OpenMesh']]],
  ['vec3f',['Vec3f',['../a00734.html#aeb4e43a28974a16e6131fd93eef1ebfe',1,'OpenMesh']]],
  ['vec3i',['Vec3i',['../a00734.html#af92a712cafeaf803dcff54fc0d87ea39',1,'OpenMesh']]],
  ['vec3s',['Vec3s',['../a00734.html#a411cf03ddab2d7f6b90a3d3be78ce3f5',1,'OpenMesh']]],
  ['vec3uc',['Vec3uc',['../a00734.html#a67dc20adf1fac6b637fe8a39e532b041',1,'OpenMesh']]],
  ['vec3ui',['Vec3ui',['../a00734.html#add9e9d83d036c288a1340a6184422ddb',1,'OpenMesh']]],
  ['vec3us',['Vec3us',['../a00734.html#a5d8ba1713764af25cd8f32b26d93fc41',1,'OpenMesh']]],
  ['vec4c',['Vec4c',['../a00734.html#a4a3b8ef5a9d726d90a0dfabe2aea36a6',1,'OpenMesh']]],
  ['vec4d',['Vec4d',['../a00734.html#a3bcb064842a6d2b08ee3b242eea73138',1,'OpenMesh']]],
  ['vec4f',['Vec4f',['../a00734.html#a9a4e7eb648204fc6bc62b7e05e3f84b0',1,'OpenMesh']]],
  ['vec4i',['Vec4i',['../a00734.html#a8ec45ce81d20088d45ba634572c9d744',1,'OpenMesh']]],
  ['vec4s',['Vec4s',['../a00734.html#a91fc37d9841f414e612a3f9231b087ed',1,'OpenMesh']]],
  ['vec4uc',['Vec4uc',['../a00734.html#aa8984ab7b6286d319c155ab2180eb186',1,'OpenMesh']]],
  ['vec4ui',['Vec4ui',['../a00734.html#a5bdc89696d0cdf4311422f60ba4c225c',1,'OpenMesh']]],
  ['vec4us',['Vec4us',['../a00734.html#ad7462f143883e7390d8473f333bc2fb6',1,'OpenMesh']]],
  ['vec5c',['Vec5c',['../a00734.html#a4c0cb55b28a5d14997adff9d886c7d5a',1,'OpenMesh']]],
  ['vec5d',['Vec5d',['../a00734.html#ad124b4ce0e6019898633ca23e38ab805',1,'OpenMesh']]],
  ['vec5f',['Vec5f',['../a00734.html#a9648907b48d27d4c81c7fadf1d3fa097',1,'OpenMesh']]],
  ['vec5i',['Vec5i',['../a00734.html#a4659c03a9282f207cf97c3498b6d0790',1,'OpenMesh']]],
  ['vec5s',['Vec5s',['../a00734.html#a557ae0219c1a40087edfe2837811aa75',1,'OpenMesh']]],
  ['vec5uc',['Vec5uc',['../a00734.html#a1b88072f7430ff127321dde098f1ea8d',1,'OpenMesh']]],
  ['vec5ui',['Vec5ui',['../a00734.html#a4dbbf47dd4d4d84f40888f2bfb589e56',1,'OpenMesh']]],
  ['vec5us',['Vec5us',['../a00734.html#aeb1e6e64620499c19a939f3b156c394a',1,'OpenMesh']]],
  ['vec6c',['Vec6c',['../a00734.html#a7f7a4365cd8f1903d0637be347a72f98',1,'OpenMesh']]],
  ['vec6d',['Vec6d',['../a00734.html#abbfc3a8d649cdc8972bdfedf4e4c7dfb',1,'OpenMesh']]],
  ['vec6f',['Vec6f',['../a00734.html#a931f95cd5b7cff67962ebcf1cc39385e',1,'OpenMesh']]],
  ['vec6i',['Vec6i',['../a00734.html#a8206c7c818a3c5e8c61ab65ae8e24f0f',1,'OpenMesh']]],
  ['vec6s',['Vec6s',['../a00734.html#aed8aa387c4eb3f08a821dce2e7d8c2b8',1,'OpenMesh']]],
  ['vec6uc',['Vec6uc',['../a00734.html#a9265a7b2911acb2534c8ce8414385706',1,'OpenMesh']]],
  ['vec6ui',['Vec6ui',['../a00734.html#a9a4653fdfb7173d52df9f076113d2add',1,'OpenMesh']]],
  ['vec6us',['Vec6us',['../a00734.html#adf3cb3182d1cdc909bafd8dd10e8f305',1,'OpenMesh']]],
  ['veccwiter',['VECCWIter',['../a00247.html#af72d35754eaec966814952440b333d73',1,'OpenMesh::PolyConnectivity']]],
  ['vector_5fcast',['vector_cast',['../a00734.html#a6bd9c6555d30f75e4de638b1c782ad42',1,'OpenMesh::vector_cast(const src_t &amp;_src, dst_t &amp;_dst, GenProg::Int2Type&lt; n &gt;)'],['../a00734.html#a4c9027c3e378b0e16c62f6bc7b61fdf9',1,'OpenMesh::vector_cast(const src_t &amp;, dst_t &amp;, GenProg::Int2Type&lt; 0 &gt;)'],['../a00734.html#ad0d391915b6a74c2ed33aff7f78f1175',1,'OpenMesh::vector_cast(const src_t &amp;_src)']]],
  ['vector_5fcaster_3c_20osg_3a_3avec3d_2c_20osg_3a_3apnt3d_20_3e',['vector_caster&lt; osg::Vec3d, osg::Pnt3d &gt;',['../a00291.html',1,'OpenMesh']]],
  ['vector_5fcaster_3c_20osg_3a_3avec3f_2c_20osg_3a_3apnt3f_20_3e',['vector_caster&lt; osg::Vec3f, osg::Pnt3f &gt;',['../a00292.html',1,'OpenMesh']]],
  ['vector_5fcaster_3c_20osg_3a_3avec4d_2c_20osg_3a_3apnt4d_20_3e',['vector_caster&lt; osg::Vec4d, osg::Pnt4d &gt;',['../a00293.html',1,'OpenMesh']]],
  ['vector_5fcaster_3c_20osg_3a_3avec4f_2c_20osg_3a_3apnt4f_20_3e',['vector_caster&lt; osg::Vec4f, osg::Pnt4f &gt;',['../a00294.html',1,'OpenMesh']]],
  ['vector_5fcopy',['vector_copy',['../a00734.html#ae0287f19025fd1b249471f63a8c47d71',1,'OpenMesh::vector_copy(const src_t &amp;_src, dst_t &amp;_dst, GenProg::Int2Type&lt; n &gt;)'],['../a00734.html#aa8c0ae097da7611ac569dcdd7f9c88d6',1,'OpenMesh::vector_copy(const src_t &amp;, dst_t &amp;, GenProg::Int2Type&lt; 0 &gt;)']]],
  ['vector_5ftraits',['vector_traits',['../a00295.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3acolor3f_20_3e',['vector_traits&lt; osg::Color3f &gt;',['../a00296.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3acolor3ub_20_3e',['vector_traits&lt; osg::Color3ub &gt;',['../a00297.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3acolor4f_20_3e',['vector_traits&lt; osg::Color4f &gt;',['../a00298.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3acolor4ub_20_3e',['vector_traits&lt; osg::Color4ub &gt;',['../a00299.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3apnt2d_20_3e',['vector_traits&lt; osg::Pnt2d &gt;',['../a00300.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3apnt2f_20_3e',['vector_traits&lt; osg::Pnt2f &gt;',['../a00301.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3apnt3d_20_3e',['vector_traits&lt; osg::Pnt3d &gt;',['../a00302.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3apnt3f_20_3e',['vector_traits&lt; osg::Pnt3f &gt;',['../a00303.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3apnt4d_20_3e',['vector_traits&lt; osg::Pnt4d &gt;',['../a00304.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3apnt4f_20_3e',['vector_traits&lt; osg::Pnt4f &gt;',['../a00305.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3avec2f_20_3e',['vector_traits&lt; osg::Vec2f &gt;',['../a00306.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3avec3d_20_3e',['vector_traits&lt; osg::Vec3d &gt;',['../a00307.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3avec3f_20_3e',['vector_traits&lt; osg::Vec3f &gt;',['../a00308.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3avec4d_20_3e',['vector_traits&lt; osg::Vec4d &gt;',['../a00309.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3avec4f_20_3e',['vector_traits&lt; osg::Vec4f &gt;',['../a00310.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20osg_3a_3avec4ub_20_3e',['vector_traits&lt; osg::Vec4ub &gt;',['../a00311.html',1,'OpenMesh']]],
  ['vector_5ftraits_3c_20point_20_3e',['vector_traits&lt; Point &gt;',['../a00295.html',1,'OpenMesh']]],
  ['vector_5ftype',['vector_type',['../a00313.html#a0546f0353e5426d0813d2cc39379517a',1,'VectorT::vector_type()'],['../a00295.html#a18e9f5e25f8f75da8e609efc2baa15ac',1,'OpenMesh::vector_traits::vector_type()']]],
  ['vectorize',['vectorize',['../a00313.html#ad8e719cc4e5e154ad42d00657513a7f7',1,'VectorT']]],
  ['vectorized',['vectorized',['../a00313.html#aab126c6306e691aaf0fecc88751624ad',1,'VectorT']]],
  ['vectort',['VectorT',['../a00312.html',1,'OpenMesh']]],
  ['vectort',['VectorT',['../a00313.html',1,'VectorT&lt; Scalar, N &gt;'],['../a00313.html#ada1d3d22f54c2934ec6bfba30ec76a13',1,'VectorT::VectorT()'],['../a00313.html#a520dfe1877f57193b09a4b1dc1032257',1,'VectorT::VectorT(const Scalar &amp;v)'],['../a00313.html#a95125d93a1d3f168c5e8d01b829f5c5e',1,'VectorT::VectorT(const Scalar _values[N])'],['../a00313.html#ab1ad027c77dcde0c04b201ff7ef72c15',1,'VectorT::VectorT(const VectorT&lt; otherScalarType, N &gt; &amp;_rhs)']]],
  ['vectort_3c_20float_2c_203_20_3e',['VectorT&lt; float, 3 &gt;',['../a00312.html',1,'OpenMesh']]],
  ['vectort_3c_20float_2c_204_20_3e',['VectorT&lt; float, 4 &gt;',['../a00313.html',1,'VectorT&lt; float, 4 &gt;'],['../a00312.html',1,'OpenMesh::VectorT&lt; float, 4 &gt;']]],
  ['vectort_3c_20scalar_2c_203_20_3e',['VectorT&lt; Scalar, 3 &gt;',['../a00312.html',1,'OpenMesh']]],
  ['vecwiter',['VECWIter',['../a00247.html#a77aee8ed931496c59c2eeb5cf0fe7971',1,'OpenMesh::PolyConnectivity']]],
  ['veiter',['VEIter',['../a00247.html#abd967c39959527be8aa20b7324def74a',1,'OpenMesh::PolyConnectivity']]],
  ['vertex',['vertex',['../a00198.html#a5aa8e1d69e6adb6ec266f4903926a1e2',1,'OpenMesh::Concepts::KernelT::vertex(VertexHandle _h) const '],['../a00198.html#a12073d0e44a41e89e8fbb4f3ce77b7ee',1,'OpenMesh::Concepts::KernelT::vertex(VertexHandle _h)'],['../a00198.html#af68122190c9f3df2b6af4d670ee767e4',1,'OpenMesh::Concepts::KernelT::Vertex()'],['../a00250.html#a03e6fd1a2fc91d4144374fd28dfbecee',1,'OpenMesh::PolyMeshT::Vertex()']]],
  ['vertex_5fhandle',['vertex_handle',['../a00183.html#afb232babadb9e5535128a0f058d2f9be',1,'OpenMesh::Concepts::MeshItems::HalfedgeT::vertex_handle()'],['../a00198.html#aa8d02e4a5a3281bf7770c9a92beabe88',1,'OpenMesh::Concepts::KernelT::vertex_handle()']]],
  ['vertex_5fsplit',['vertex_split',['../a00279.html#a142b267bf7eaa2e57b66a0035df43f10',1,'OpenMesh::TriConnectivity::vertex_split()'],['../a00284.html#a4868b772cb7a9d7bb8d94854dfb82868',1,'OpenMesh::TriMeshT::vertex_split(Point _v0_point, VertexHandle _v1, VertexHandle _vl, VertexHandle _vr)'],['../a00284.html#ac58e0af86ecd0bbc5e821ecd8c8beaff',1,'OpenMesh::TriMeshT::vertex_split(VertexHandle _v0, VertexHandle _v1, VertexHandle _vl, VertexHandle _vr)']]],
  ['vertexattributes',['VertexAttributes',['../a00507.html#a427ff443d5e47c76b9c45a29213e63db',1,'Traits.hh']]],
  ['vertexcolor',['VertexColor',['../a00244.html#a9f4f797b08c045b611eaa6f8d149da21af7b6bb87f12fdfe5c9a8f8e1ce9325c7',1,'OpenMesh::IO::Options']]],
  ['vertexedgeccwiter',['VertexEdgeCCWIter',['../a00247.html#a5229b57fc8c2c9b69fa2f98437c7d3f1',1,'OpenMesh::PolyConnectivity']]],
  ['vertexedgecwiter',['VertexEdgeCWIter',['../a00247.html#aae1b50f081a905690597f0b87571a4f1',1,'OpenMesh::PolyConnectivity']]],
  ['vertexedgeiter',['VertexEdgeIter',['../a00247.html#a4181d76bc1149576e77d7daa6f8452bc',1,'OpenMesh::PolyConnectivity::VertexEdgeIter()'],['../a00250.html#a68dd0d2773f837cbfb525d7208dedde0',1,'OpenMesh::PolyMeshT::VertexEdgeIter()']]],
  ['vertexfaceccwiter',['VertexFaceCCWIter',['../a00247.html#acaa33dd1fb54414682a9ab7e90352cc2',1,'OpenMesh::PolyConnectivity']]],
  ['vertexfacecwiter',['VertexFaceCWIter',['../a00247.html#a3972257edd496bd6b1affc5d371c3638',1,'OpenMesh::PolyConnectivity']]],
  ['vertexfaceiter',['VertexFaceIter',['../a00247.html#a1400319f94679eebfaab592ac19ebedb',1,'OpenMesh::PolyConnectivity::VertexFaceIter()'],['../a00250.html#a1ebe8b94ca30db3af44c809ab3ee7247',1,'OpenMesh::PolyMeshT::VertexFaceIter()']]],
  ['vertexhandle',['VertexHandle',['../a00314.html',1,'OpenMesh']]],
  ['vertexhandle',['VertexHandle',['../a00198.html#ad595781d23c223ce056c6a8f31eda9d5',1,'OpenMesh::Concepts::KernelT::VertexHandle()'],['../a00250.html#a0fc18e13d70825938274e3faf7b55e01',1,'OpenMesh::PolyMeshT::VertexHandle()']]],
  ['vertexihalfedgeccwiter',['VertexIHalfedgeCCWIter',['../a00247.html#a3ae1cceb72002e179948851ff820a4a7',1,'OpenMesh::PolyConnectivity']]],
  ['vertexihalfedgecwiter',['VertexIHalfedgeCWIter',['../a00247.html#a5610d51f0693c3cf3333d11dc040b261',1,'OpenMesh::PolyConnectivity']]],
  ['vertexihalfedgeiter',['VertexIHalfedgeIter',['../a00247.html#a5b228884a6385b324b256263eb8254b1',1,'OpenMesh::PolyConnectivity::VertexIHalfedgeIter()'],['../a00250.html#a437621f3901a93d0ebf8cdceac8e2939',1,'OpenMesh::PolyMeshT::VertexIHalfedgeIter()']]],
  ['vertexiter',['VertexIter',['../a00247.html#a4b95dd01ec6e77abfe8cc06b5536985d',1,'OpenMesh::PolyConnectivity']]],
  ['vertexitert',['VertexIterT',['../a00315.html',1,'OpenMesh::Iterators']]],
  ['vertexnormal',['VertexNormal',['../a00244.html#a9f4f797b08c045b611eaa6f8d149da21ad989c6d671050e12953b648c4c72dded',1,'OpenMesh::IO::Options']]],
  ['vertexohalfedgeccwiter',['VertexOHalfedgeCCWIter',['../a00247.html#a93229683bc5d32e6adc94821916823c5',1,'OpenMesh::PolyConnectivity']]],
  ['vertexohalfedgecwiter',['VertexOHalfedgeCWIter',['../a00247.html#a11f3f7d2f46d47e920aa3ad60246f2a0',1,'OpenMesh::PolyConnectivity']]],
  ['vertexohalfedgeiter',['VertexOHalfedgeIter',['../a00247.html#a162054e1fc345ce1df9cdfda7433ffc0',1,'OpenMesh::PolyConnectivity::VertexOHalfedgeIter()'],['../a00250.html#a6549eda743520c8a7aa3dfe6a37b2468',1,'OpenMesh::PolyMeshT::VertexOHalfedgeIter()']]],
  ['vertext',['VertexT',['../a00320.html#ac714e165662433c27dbc482b7a524201',1,'OpenMesh::Concepts::MeshItems::VertexT']]],
  ['vertext',['VertexT',['../a00316.html',1,'OpenMesh::Subdivider::Uniform::CompositeTraits']]],
  ['vertext',['VertexT',['../a00317.html',1,'AnalyzerTraits']]],
  ['vertext',['VertexT',['../a00318.html',1,'OpenMesh::VDPM::MeshTraits']]],
  ['vertext',['VertexT',['../a00319.html',1,'MyTraits']]],
  ['vertext',['VertexT',['../a00320.html',1,'OpenMesh::Concepts::MeshItems']]],
  ['vertext',['VertexT',['../a00321.html',1,'OpenMesh::Subdivider::Adaptive::CompositeTraits']]],
  ['vertextexcoord',['VertexTexCoord',['../a00244.html#a9f4f797b08c045b611eaa6f8d149da21ae9e664738c4c48ac057770fb08a723f0',1,'OpenMesh::IO::Options']]],
  ['vertextraits',['VertexTraits',['../a00507.html#aa5146d858418fcb93715406a6ce8e30f',1,'Traits.hh']]],
  ['vertexvertexccwiter',['VertexVertexCCWIter',['../a00247.html#ac9ee8b2c9188f3e72b26cc78e6360e38',1,'OpenMesh::PolyConnectivity']]],
  ['vertexvertexcwiter',['VertexVertexCWIter',['../a00247.html#a71b3cb191ead32cea423aeadd870ed67',1,'OpenMesh::PolyConnectivity']]],
  ['vertexvertexiter',['VertexVertexIter',['../a00247.html#a8d0f5fd57de17e83ced449a9deac667b',1,'OpenMesh::PolyConnectivity::VertexVertexIter()'],['../a00250.html#adc7d422e2ce13141e8291f7d29f7ecef',1,'OpenMesh::PolyMeshT::VertexVertexIter()']]],
  ['vertices',['vertices',['../a00247.html#a282d8cf19d609b1db6300810088692e2',1,'OpenMesh::PolyConnectivity']]],
  ['vertices_5fbegin',['vertices_begin',['../a00198.html#ac15277b02babdabf254e35998c51c19d',1,'OpenMesh::Concepts::KernelT::vertices_begin()'],['../a00198.html#a65bd222341bd879f788f57191a2004ed',1,'OpenMesh::Concepts::KernelT::vertices_begin() const '],['../a00247.html#a9990e9d0159d499ce381294a0486dc2e',1,'OpenMesh::PolyConnectivity::vertices_begin()'],['../a00247.html#aba771c6ab4abb8a8de90767cd30f1bdd',1,'OpenMesh::PolyConnectivity::vertices_begin() const ']]],
  ['vertices_5fempty',['vertices_empty',['../a00198.html#acf25db747495e4f86e3abaaa68014a0e',1,'OpenMesh::Concepts::KernelT']]],
  ['vertices_5fend',['vertices_end',['../a00198.html#a4d26fd2c29976f43be622cd1bc8d80ed',1,'OpenMesh::Concepts::KernelT::vertices_end()'],['../a00198.html#a6a4c47adc324a007b8de88ca5aaa1932',1,'OpenMesh::Concepts::KernelT::vertices_end() const '],['../a00247.html#ae01a39ca6f8ebc0dacdaa0fa809a70ed',1,'OpenMesh::PolyConnectivity::vertices_end()'],['../a00247.html#ab08ec27924584cf3f8775f8ac53006a6',1,'OpenMesh::PolyConnectivity::vertices_end() const ']]],
  ['vertices_5fsbegin',['vertices_sbegin',['../a00247.html#a6569b733af46d0fe800d9d91fdcea8dd',1,'OpenMesh::PolyConnectivity::vertices_sbegin()'],['../a00247.html#a96d44424b2ec059d802d5e3b87ad7288',1,'OpenMesh::PolyConnectivity::vertices_sbegin() const ']]],
  ['vf',['VF',['../a00117.html#a35388243679b29082a346088779e4e86',1,'OpenMesh::Subdivider::Uniform::CompositeT']]],
  ['vf',['VF',['../a00322.html',1,'OpenMesh::Subdivider::Adaptive']]],
  ['vf_5fbegin',['vf_begin',['../a00247.html#ae6b36c4a6b678638e238321e4fc795e1',1,'OpenMesh::PolyConnectivity']]],
  ['vf_5fccwbegin',['vf_ccwbegin',['../a00247.html#a84e3ed334ce6c11e431a74794290e9af',1,'OpenMesh::PolyConnectivity']]],
  ['vf_5fccwend',['vf_ccwend',['../a00247.html#a909b602d644cae986478329d30793556',1,'OpenMesh::PolyConnectivity']]],
  ['vf_5fccwiter',['vf_ccwiter',['../a00247.html#a59216b538b18da04b718fa14c690c663',1,'OpenMesh::PolyConnectivity']]],
  ['vf_5fcwbegin',['vf_cwbegin',['../a00247.html#ab4583ea5f6663051cc6f919fd79557f7',1,'OpenMesh::PolyConnectivity']]],
  ['vf_5fcwend',['vf_cwend',['../a00247.html#a84c4a23bdf89623725eeffb7e71a835b',1,'OpenMesh::PolyConnectivity']]],
  ['vf_5fcwiter',['vf_cwiter',['../a00247.html#ab369e0d484e857be7916fecfaea527aa',1,'OpenMesh::PolyConnectivity']]],
  ['vf_5fend',['vf_end',['../a00247.html#aef190bf31e1bb4efda69b4edd1c944c8',1,'OpenMesh::PolyConnectivity']]],
  ['vf_5fiter',['vf_iter',['../a00247.html#a25860bb9999a9b507b3a80e2e37a2e82',1,'OpenMesh::PolyConnectivity']]],
  ['vf_5frange',['vf_range',['../a00247.html#a709c5b45f345a98067f996ca6fb0f414',1,'OpenMesh::PolyConnectivity']]],
  ['vfa',['VFa',['../a00117.html#a391faa77341e9e7fa268a05745d170de',1,'OpenMesh::Subdivider::Uniform::CompositeT::VFa(Coeff &amp;_coeff)'],['../a00117.html#ae7041649c35a328ec0dde220604ef41e',1,'OpenMesh::Subdivider::Uniform::CompositeT::VFa(scalar_t _alpha)']]],
  ['vfccwiter',['VFCCWIter',['../a00247.html#a1a34ecf2957201270b186d7bb57eaab2',1,'OpenMesh::PolyConnectivity']]],
  ['vfcwiter',['VFCWIter',['../a00247.html#ad392a12729ba6a63145d4a616602d06d',1,'OpenMesh::PolyConnectivity']]],
  ['vfiter',['VFIter',['../a00247.html#a4a1e926552238cc5c5221ad4c7f32006',1,'OpenMesh::PolyConnectivity']]],
  ['vfront',['VFront',['../a00323.html',1,'OpenMesh::VDPM']]],
  ['vhandle',['VHandle',['../a00247.html#a149e263ec1b2b76be4ffe40e7900f2e2',1,'OpenMesh::PolyConnectivity']]],
  ['vhierarchy',['VHierarchy',['../a00324.html',1,'OpenMesh::VDPM']]],
  ['vhierarchynode',['VHierarchyNode',['../a00325.html',1,'OpenMesh::VDPM']]],
  ['vhierarchynodecontainer',['VHierarchyNodeContainer',['../a00754.html#a2b54f71ece0193577af8155cece72004',1,'OpenMesh::VDPM']]],
  ['vhierarchynodehandle',['VHierarchyNodeHandle',['../a00326.html',1,'OpenMesh::VDPM']]],
  ['vhierarchynodehandlecontainer',['VHierarchyNodeHandleContainer',['../a00754.html#a503c22d36bf2bdb5daeccd78c29053fd',1,'OpenMesh::VDPM']]],
  ['vhierarchynodehandlelist',['VHierarchyNodeHandleList',['../a00754.html#aa201c711fa128b2693fab7cd74997a06',1,'OpenMesh::VDPM']]],
  ['vhierarchynodeindex',['VHierarchyNodeIndex',['../a00327.html',1,'OpenMesh::VDPM']]],
  ['vhierarchynodeindexcontainer',['VHierarchyNodeIndexContainer',['../a00754.html#ab09da442ea7b900693e5004b00bd174f',1,'OpenMesh::VDPM']]],
  ['vhierarchywindow',['VHierarchyWindow',['../a00328.html',1,'OpenMesh::VDPM']]],
  ['viewingparameters',['ViewingParameters',['../a00329.html',1,'OpenMesh::VDPM']]],
  ['vih_5fbegin',['vih_begin',['../a00247.html#a0b5a4dfcd88f458a71bb65e0250e5277',1,'OpenMesh::PolyConnectivity']]],
  ['vih_5fccwbegin',['vih_ccwbegin',['../a00247.html#aaee1ba7b5dfea07fc19a36c60f1b64ec',1,'OpenMesh::PolyConnectivity']]],
  ['vih_5fccwend',['vih_ccwend',['../a00247.html#a8bc1c4f2418841f2d8a3c8873700f6f7',1,'OpenMesh::PolyConnectivity']]],
  ['vih_5fccwiter',['vih_ccwiter',['../a00247.html#a023bf6669e54908923b16eb3af111a81',1,'OpenMesh::PolyConnectivity']]],
  ['vih_5fcwbegin',['vih_cwbegin',['../a00247.html#acd3997b8f5ae353a0beadb7e480c1fca',1,'OpenMesh::PolyConnectivity']]],
  ['vih_5fcwend',['vih_cwend',['../a00247.html#a790109e1326c1cc9f3544f1a88074081',1,'OpenMesh::PolyConnectivity']]],
  ['vih_5fcwiter',['vih_cwiter',['../a00247.html#a677196e95cd524a3f6b86c149ad3d323',1,'OpenMesh::PolyConnectivity']]],
  ['vih_5fend',['vih_end',['../a00247.html#a15cd3c0698c65f96e5114015b32b5c47',1,'OpenMesh::PolyConnectivity']]],
  ['vih_5fiter',['vih_iter',['../a00247.html#ad107901645041fc7f0662ef92c3a079b',1,'OpenMesh::PolyConnectivity']]],
  ['vih_5frange',['vih_range',['../a00247.html#a16544bc4aeb42ef7271ff9e610e9a4e4',1,'OpenMesh::PolyConnectivity']]],
  ['vihiccwter',['VIHICCWter',['../a00247.html#aec74483cb8df2b7dd172b55aab3a9ff6',1,'OpenMesh::PolyConnectivity']]],
  ['vihicwter',['VIHICWter',['../a00247.html#abd69e586a05546b918aee33a4982cd96',1,'OpenMesh::PolyConnectivity']]],
  ['vihiter',['VIHIter',['../a00247.html#a5a78f25558aaff53e576ece45047c444',1,'OpenMesh::PolyConnectivity']]],
  ['viter',['VIter',['../a00247.html#a5ce800a66e9a27e7c8bb04babce2d2fb',1,'OpenMesh::PolyConnectivity']]],
  ['vl',['vl',['../a00110.html#a4d6ceec9090fb5a282e3a2f842962597',1,'OpenMesh::Decimater::CollapseInfoT::vl()'],['../a00192.html#a03ccd426624161b9565c1f4868a2d2c7',1,'OpenMesh::Decimater::ModProgMeshT::Info::vl()']]],
  ['vlv1',['vlv1',['../a00110.html#a0d3ab34ba78e36e61066d0b26bdb3e4e',1,'OpenMesh::Decimater::CollapseInfoT']]],
  ['voh_5fbegin',['voh_begin',['../a00247.html#ae9e88a9b6af59171867f0266e052d911',1,'OpenMesh::PolyConnectivity']]],
  ['voh_5fccwbegin',['voh_ccwbegin',['../a00247.html#a202518ac3b78c6a585b629688420e83a',1,'OpenMesh::PolyConnectivity']]],
  ['voh_5fccwend',['voh_ccwend',['../a00247.html#a87041e9d715381f22b69250334df0d01',1,'OpenMesh::PolyConnectivity']]],
  ['voh_5fccwiter',['voh_ccwiter',['../a00247.html#a51e57072135fb8718cea53c072b024d1',1,'OpenMesh::PolyConnectivity']]],
  ['voh_5fcwbegin',['voh_cwbegin',['../a00247.html#a2ee9676f7f8e8dd80e3aa049e17a06a9',1,'OpenMesh::PolyConnectivity']]],
  ['voh_5fcwend',['voh_cwend',['../a00247.html#ae4dfb91e46c7f7c9920040c95c2e1bb1',1,'OpenMesh::PolyConnectivity']]],
  ['voh_5fcwiter',['voh_cwiter',['../a00247.html#a37d85371c1d38042a2a6bf86ea7bf947',1,'OpenMesh::PolyConnectivity']]],
  ['voh_5fend',['voh_end',['../a00247.html#a305deca13fb343ec6f2fe222b953cbd2',1,'OpenMesh::PolyConnectivity']]],
  ['voh_5fiter',['voh_iter',['../a00247.html#ac93ceccd63aed16bcab88930c89ffbbb',1,'OpenMesh::PolyConnectivity']]],
  ['voh_5frange',['voh_range',['../a00247.html#a3a16b2d44225b8786ccfb07104dd5c25',1,'OpenMesh::PolyConnectivity']]],
  ['vohccwiter',['VOHCCWIter',['../a00247.html#ab207ad32713a6c8bab6f3d3954321e33',1,'OpenMesh::PolyConnectivity']]],
  ['vohcwiter',['VOHCWIter',['../a00247.html#a956cd3f02b3c9e65783dd9fa937656c4',1,'OpenMesh::PolyConnectivity']]],
  ['vohiter',['VOHIter',['../a00247.html#ac1ccb41e21e85e00e558d185d2e29afa',1,'OpenMesh::PolyConnectivity']]],
  ['vprophandlet',['VPropHandleT',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20bool_20_3e',['VPropHandleT&lt; bool &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20color_20_3e',['VPropHandleT&lt; Color &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20float_20_3e',['VPropHandleT&lt; float &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20geometry_3a_3aquadrict_3c_20double_20_3e_20_3e',['VPropHandleT&lt; Geometry::QuadricT&lt; double &gt; &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20halfedgehandle_20_3e',['VPropHandleT&lt; HalfedgeHandle &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20int_20_3e',['VPropHandleT&lt; int &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20level_5ft_20_3e',['VPropHandleT&lt; level_t &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20normal_20_3e',['VPropHandleT&lt; Normal &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20normaltype_20_3e',['VPropHandleT&lt; NormalType &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20openmesh_3a_3aattributes_3a_3astatusinfo_20_3e',['VPropHandleT&lt; OpenMesh::Attributes::StatusInfo &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20point_20_3e',['VPropHandleT&lt; Point &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20scalar_20_3e',['VPropHandleT&lt; Scalar &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20size_5ft_20_3e',['VPropHandleT&lt; size_t &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20statusinfo_20_3e',['VPropHandleT&lt; StatusInfo &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20texcoord_20_3e',['VPropHandleT&lt; TexCoord &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20texcoord1d_20_3e',['VPropHandleT&lt; TexCoord1D &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20texcoord2d_20_3e',['VPropHandleT&lt; TexCoord2D &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20texcoord3d_20_3e',['VPropHandleT&lt; TexCoord3D &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20typename_20mesh_5ft_3a_3apoint_20_3e',['VPropHandleT&lt; typename mesh_t::Point &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20typename_20meshtype_3a_3apoint_20_3e',['VPropHandleT&lt; typename MeshType::Point &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20typename_20openmesh_3a_3apolymesh_5farraykernelt_3a_3anormal_20_3e',['VPropHandleT&lt; typename OpenMesh::PolyMesh_ArrayKernelT::Normal &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprophandlet_3c_20vertexdata_20_3e',['VPropHandleT&lt; VertexData &gt;',['../a00330.html',1,'OpenMesh']]],
  ['vprops_5freserve',['vprops_reserve',['../a00095.html#ae2f651eca3c349658f55fafea8ff314b',1,'OpenMesh::BaseKernel']]],
  ['vprops_5fresize',['vprops_resize',['../a00095.html#a275545ba650483b38a07f0127fac1f04',1,'OpenMesh::BaseKernel']]],
  ['vprops_5fresize_5fif_5fsmaller',['vprops_resize_if_smaller',['../a00095.html#af6d9e8b13d4dc50ea3ffe88ae0ab425d',1,'OpenMesh::BaseKernel']]],
  ['vr',['vr',['../a00110.html#ad65dfec5ec35931c6aaac3587b0fd55e',1,'OpenMesh::Decimater::CollapseInfoT::vr()'],['../a00192.html#a297e1149aedb6885bfe5588157b9488d',1,'OpenMesh::Decimater::ModProgMeshT::Info::vr()']]],
  ['vrv0',['vrv0',['../a00110.html#a14f222f628f5256dd26dbe495a6452d2',1,'OpenMesh::Decimater::CollapseInfoT']]],
  ['vv',['VV',['../a00331.html',1,'OpenMesh::Subdivider::Adaptive']]],
  ['vv',['VV',['../a00117.html#add3815ae0c361f86d6540a2f73e36ebc',1,'OpenMesh::Subdivider::Uniform::CompositeT']]],
  ['vv_5fbegin',['vv_begin',['../a00247.html#abce650f6a0e3c99ab3785b78c1c890b3',1,'OpenMesh::PolyConnectivity']]],
  ['vv_5fccwbegin',['vv_ccwbegin',['../a00247.html#a45ad70fa86558e95d5539a42f7b84cc7',1,'OpenMesh::PolyConnectivity']]],
  ['vv_5fccwend',['vv_ccwend',['../a00247.html#a7d8670eb4cbdaa9dbd88369ecb4a57a9',1,'OpenMesh::PolyConnectivity']]],
  ['vv_5fccwiter',['vv_ccwiter',['../a00247.html#aa01beaae834518c83c55b2eae12ca19f',1,'OpenMesh::PolyConnectivity']]],
  ['vv_5fcwbegin',['vv_cwbegin',['../a00247.html#ab553c1e3fb198d27c3dc4358e6254645',1,'OpenMesh::PolyConnectivity']]],
  ['vv_5fcwend',['vv_cwend',['../a00247.html#a9ad2eec911278d900ef0883b63ff3b05',1,'OpenMesh::PolyConnectivity']]],
  ['vv_5fcwiter',['vv_cwiter',['../a00247.html#a9e3ede3d71ba18403d34f16d6dd2db4c',1,'OpenMesh::PolyConnectivity']]],
  ['vv_5fend',['vv_end',['../a00247.html#ad2921072a89489f12bbab9138a416bda',1,'OpenMesh::PolyConnectivity']]],
  ['vv_5fiter',['vv_iter',['../a00247.html#a68c1388ce7b5ce1cc9cf8825293ac801',1,'OpenMesh::PolyConnectivity']]],
  ['vv_5frange',['vv_range',['../a00247.html#a99752d332e767853197540c42908460a',1,'OpenMesh::PolyConnectivity']]],
  ['vvc',['VVc',['../a00332.html',1,'OpenMesh::Subdivider::Adaptive']]],
  ['vvc',['VVc',['../a00117.html#a321e740e4f6cff41adfcf843c82e33f0',1,'OpenMesh::Subdivider::Uniform::CompositeT::VVc(Coeff &amp;_coeff)'],['../a00117.html#ab95a7d8ea472a57bfc80fd5f6c6a5654',1,'OpenMesh::Subdivider::Uniform::CompositeT::VVc(scalar_t _c)']]],
  ['vvccwiter',['VVCCWIter',['../a00247.html#a0ba1b745e4e19fa1441ad2cb1f078617',1,'OpenMesh::PolyConnectivity']]],
  ['vvcwiter',['VVCWIter',['../a00247.html#a0354c25f916de79fc45170bf6a4caf12',1,'OpenMesh::PolyConnectivity']]],
  ['vviter',['VVIter',['../a00247.html#a0a0e01cb2ca56d75e7ab530ffb96bc70',1,'OpenMesh::PolyConnectivity']]]
];
